@@ -12,7 +12,7 @@ from platform import system
 from tkinter import Frame, Label, Button, StringVar, font, N, S, W, E, SUNKEN
 
 from PIL import ImageTk, Image
-from pyubx2 import UBXMessage
+from pyubx2.ubxhelpers import dop2str
 
 from .globals import (
     deg2dmm,
@@ -275,7 +275,7 @@ class BannerFrame(Frame):
         """
         Update connection status icon
 
-        :param status: connection status as integer (0,1,2)
+        :param int status: connection status as integer (0,1,2)
         """
 
         if status == CONNECTED:
@@ -317,8 +317,8 @@ class BannerFrame(Frame):
         """
         Update position
 
-        :param disp_format: degrees display format as string (DMS, DMM, DDD)
-        :param units: distance units as string (UMM, UMK, UI, UIK)
+        :param str disp_format: degrees display format as string (DMS, DMM, DDD)
+        :param str units: distance units as string (UMM, UMK, UI, UIK)
         :param kwargs: optional key value pairs
         """
 
@@ -361,7 +361,7 @@ class BannerFrame(Frame):
         """
         Update track and ground speed
 
-        :param units: distance units as string (UMM, UMK, UI, UIK)
+        :param str units: distance units as string (UMM, UMK, UI, UIK)
         :param kwargs: optional key value pairs
         """
 
@@ -422,13 +422,13 @@ class BannerFrame(Frame):
         """
         Update precision and accuracy
 
-        :param units: distance units as string (UMM, UMK, UI, UIK)
+        :param str units: distance units as string (UMM, UMK, UI, UIK)
         :param kwargs: optional key value pairs
         """
 
         if "dop" in kwargs:
             dop = kwargs["dop"]
-            self._dop.set(str(dop) + " " + UBXMessage.dop2str(dop))
+            self._dop.set(str(dop) + " " + dop2str(dop))
         if "hdop" in kwargs and "vdop" in kwargs:
             self._hvdop.set(
                 "hdop " + str(kwargs["hdop"]) + "\nvdop " + str(kwargs["vdop"])
