@@ -12,7 +12,7 @@ Created on 30 Sep 2020
 from datetime import datetime
 from pyubx2 import UBXMessage, POLL, UBX_MSGIDS
 from pyubx2.ubxhelpers import itow2utc, gpsfix2str
-from .globals import svid2gnssid, GLONASS_NMEA, HIDE_NULL_GNSS
+from .globals import svid2gnssid, GLONASS_NMEA, GNSS_HIDE_NULL
 
 BOTH = 3
 UBX = 1
@@ -352,6 +352,7 @@ class UBXHandler:
         :param UBXMessage data: NAV-SAT parsed message
         """
 
+        show_zero = self.__app.frm_settings.get_settings()["zerosignal"]
         try:
             self.gsv_data = []
             num_siv = int(data.numCh)
@@ -366,7 +367,7 @@ class UBXHandler:
                 elev = getattr(data, "elev" + idx)
                 azim = getattr(data, "azim" + idx)
                 cno = getattr(data, "cno" + idx)
-                if cno == 0 and HIDE_NULL_GNSS:  # omit sats with zero cno
+                if cno == 0 and not show_zero:  # omit sats with zero signal
                     continue
                 self.gsv_data.append((gnssId, svid, elev, azim, cno))
             self.__app.frm_banner.update_banner(siv=len(self.gsv_data))
@@ -385,6 +386,7 @@ class UBXHandler:
         :param UBXMessage data: NAV-SVINFO parsed message
         """
 
+        show_zero = self.__app.frm_settings.get_settings()["zerosignal"]
         try:
             self.gsv_data = []
             num_siv = int(data.numCh)
@@ -396,10 +398,10 @@ class UBXHandler:
                 elev = getattr(data, "elev" + idx)
                 azim = getattr(data, "azim" + idx)
                 cno = getattr(data, "cno" + idx)
-                if cno == 0 and HIDE_NULL_GNSS:  # omit sats with zero cno
+                if cno == 0 and not show_zero:  # omit sats with zero signal
                     continue
                 self.gsv_data.append((gnssId, svid, elev, azim, cno))
-            self.__app.frm_banner.update_banner(siv=siv)
+            self.__app.frm_banner.update_banner(siv=len(self.gsv_data))
             self.__app.frm_satview.update_sats(self.gsv_data)
             self.__app.frm_graphview.update_graph(self.gsv_data, len(self.gsv_data))
         except ValueError:
